@@ -1,7 +1,7 @@
 /*
  This file is part of MOST.
 
- Copyright (c) 1991, 1999 John E. Davis
+ Copyright (c) 1991, 1999, 2002 John E. Davis
 
  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the Free
@@ -60,7 +60,7 @@ int Most_Num_Files;
 int Most_Tail_Mode = 1;
 
 #if !defined(VMS)
-static int zopen(char *file, int mode, int *size)
+static int open_compressed_file(char *file, int mode, int *size)
 {
    int fd;
    char buf[4], cmdbuf[512 + MAX_PATHLEN];
@@ -85,17 +85,29 @@ static int zopen(char *file, int mode, int *size)
 
    if (4 == read(fd, buf, 4))
      {
+	char *cmd = NULL;
+
 	if ((buf[0] == (char) 0x1f)
 	    && (buf[1] == (char) 0x8b)
 	    && (buf[2] == (char) 0x08)
 	    && ((buf[3] == (char) 0x08) || (buf[3] == (char)0x00)))
+	  {
+	     cmd = MOST_GUNZIP_POPEN_FORMAT;
+	  }
+	else if ((buf[0] == 'B') && (buf[1] == 'Z') && (buf[2] == 'h')
+	    && (buf[3] > 47))
+	  {
+	     cmd = MOST_BZIP2_POPEN_FORMAT;
+	  }
+	
+	if (cmd != NULL)
 	  {
 	     FILE *fp;
 
 	     close (fd);
 	     most_flush_message ("Uncompressing file...");
 
-	     sprintf (cmdbuf, MOST_GUNZIP_POPEN_FORMAT, file);
+	     sprintf (cmdbuf, cmd, file);
 	     fp = popen (cmdbuf, "r"); /* GLIBC doe not support "rb" */
 	     if (fp == NULL)
 	       return -1;
@@ -169,6 +181,7 @@ static int unmmap_buffer (Most_Buffer_Type *b)
 static int resync_mmap (void)
 {   
    struct stat st;
+   int line;
 
    if (Most_Buf->fd == -1)
      return 0;
@@ -182,6 +195,7 @@ static int resync_mmap (void)
    if (-1 == try_mmap_buffer (Most_Buf->fd))
      return -1;
    
+   most_goto_line (line);
    return 0;
 }
 
@@ -238,7 +252,7 @@ static int insert_file(char *file)
 	fd = open(file,O_RDONLY,"ctx=rec","mbf=8","mbc=16","rop=RAH","shr=upi,get,put");
           /* if (fd < 0) fd = open(file,O_RDONLY); */
 #else
-	fd = zopen(file, O_RDONLY, &size);
+	fd = open_compressed_file(file, O_RDONLY, &size);
 # if MOST_HAS_MMAP
 	if (0 == try_mmap_buffer (fd))
 	  return most_read_file_dsc (1);
@@ -494,7 +508,7 @@ int most_find_file(char *file)
 {
    Most_Buffer_Type *new_buf;
    int n;
-   char msg[1024], *msgp;
+   char msg[MAX_PATHLEN + 20], *msgp;
    int ret = 0;
 
    new_buf = most_create_buffer(file);
@@ -602,7 +616,8 @@ static void format_next_file (char *mbuf, int j, char *file)
 
 void most_do_next_file(int *j)
 {
-   char mbuf[256], ch, *curr_file;
+   char mbuf[256], *curr_file;
+   unsigned char ch;
 
    most_select_minibuffer();
 
@@ -620,10 +635,18 @@ void most_do_next_file(int *j)
 	SLsmg_refresh ();
 
 	ch = most_getkey();
+#ifndef IBMPC_SYSTEM
 	if (ch != '\033') break;
 	if (ch = most_getkey(), (ch != 'O') && (ch != '[')) continue;
 	if (ch = most_getkey(), (ch != 'A') && (ch != 'B')) continue;
-
+#else
+	if ((ch != 0) && (ch != 0xE0))
+	  break;
+	
+	ch = most_getkey ();
+	if (ch != 'H') ch = 'B'; else ch = 'A';
+	
+#endif
 	if (ch == 'B')
 	  {
 	     if (*j == 0) *j = Most_Num_Files;
