@@ -1,7 +1,7 @@
 /*
  This file is part of MOST.
 
- Copyright (c) 1991, 1999 John E. Davis
+ Copyright (c) 1991, 1999, 2002 John E. Davis
 
  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the Free
@@ -574,6 +574,15 @@ void most_init_keymaps (void)
    SLkm_define_key ("^@I", (FVOID_STAR) page_up_cmd, Most_Keymap);
    SLkm_define_key ("^@G", (FVOID_STAR) top_of_buffer_cmd, Most_Keymap);
    SLkm_define_key ("^@O", (FVOID_STAR) end_of_buffer_cmd, Most_Keymap);
+
+   SLkm_define_key ("\xE0H", (FVOID_STAR) previous_line_cmd, Most_Keymap);
+   SLkm_define_key ("\xE0P", (FVOID_STAR) next_line_cmd, Most_Keymap);
+   SLkm_define_key ("\xE0M", (FVOID_STAR) column_right_cmd, Most_Keymap);
+   SLkm_define_key ("\xE0K", (FVOID_STAR) column_left_cmd, Most_Keymap);
+   SLkm_define_key ("\xE0Q", (FVOID_STAR) page_down_cmd, Most_Keymap);
+   SLkm_define_key ("\xE0I", (FVOID_STAR) page_up_cmd, Most_Keymap);
+   SLkm_define_key ("\xE0G", (FVOID_STAR) top_of_buffer_cmd, Most_Keymap);
+   SLkm_define_key ("\xE0O", (FVOID_STAR) end_of_buffer_cmd, Most_Keymap);
 #endif
    SLkm_define_key ("\t", (FVOID_STAR) page_right_cmd, Most_Keymap);
    SLkm_define_key ("^", (FVOID_STAR) previous_line_cmd, Most_Keymap);
@@ -624,7 +633,7 @@ void most_init_keymaps (void)
    SLkm_define_key ("x", (FVOID_STAR) most_exit_most, Most_Keymap);
    if (SLang_Error) most_exit_error (err);
 
-   most_load_user_keymaps ();
+   (void) most_load_user_keymaps ();
 }
 
 static void sldo_key (void)
