@@ -1,7 +1,7 @@
 /*
  This file is part of MOST.
 
- Copyright (c) 1991, 1999 John E. Davis
+ Copyright (c) 1991, 1999, 2002 John E. Davis
 
  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the Free
@@ -137,7 +137,7 @@ int most_load_user_keymaps (void)
 {
 #ifndef VMS
    char filebuf[MAX_PATHLEN];
-   int len;
+   unsigned int len;
 #endif
    char *file;
 
@@ -158,12 +158,19 @@ int most_load_user_keymaps (void)
 #else
 	*filebuf = 0;
 	file = getenv ("HOME");
-	if (file != NULL) strcpy (filebuf, file);
+	if (file == NULL)
+	  return -1;
+	
+	len = strlen (file);
+	if (len + 8 >= sizeof (filebuf))   /* 8 for strlen("/.mostrc") */
+	  return -1;
+
+	strcpy (filebuf, file);
 	file = filebuf;
 
-	len = strlen (file);
-	if (len && (file[len - 1] == '/')) file[len - 1] = 0;
-	strcat (file, "/.mostrc");
+	if (len && (file[len - 1] == '/')) 
+	  len--;
+	strcpy (file + len, "/.mostrc");
 #endif
      }
    return parse_file (file);
