@@ -38,3 +38,9 @@ extern int Most_Tab_Width;
       (((x >= '0') && (x <= '9')) ? 1 : 0)
 # endif
 #endif
+
+#ifdef HAVE_SNPRINTF
+# define _SLsnprintf snprintf
+#else
+extern int _SLsnprintf (char *, unsigned int, char *, ...);
+#endif
